@@ -66,7 +66,7 @@ class ModlunkyUI:
         self._shutdown_handlers = []
         self._shutting_down = False
 
-        self.root = tk.Tk(className="Modlunky2")
+        self.root = tk.Tk(className="Modlunky2")  # Equilux Black
         self.root.title("Modlunky 2")
         self.root.geometry("950x650")
         # self.root.resizable(False, False)
@@ -99,14 +99,13 @@ class ModlunkyUI:
                 install_dir=install_dir,
             ),
         )
-        if beta:
-            self.register_tab(
-                "Levels",
-                LevelsTab(
-                    tab_control=self.tab_control,
-                    install_dir=install_dir,
-                ),
-            )
+        self.register_tab(
+            "Levels",
+            LevelsTab(
+                tab_control=self.tab_control,
+                install_dir=install_dir,
+            ),
+        )
 
         self.tab_control.bind("<<NotebookTabChanged>>", self.on_tab_change)
         self.tab_control.pack(expand=1, fill="both")
